<?php

namespace WPPOOL\SCF;

if ( ! class_exists( '\WPPOOL\SCF\Ajax' ) ) :
	final class Ajax {

		public function __construct() {
			add_action( 'wp_ajax_scf_save_settings', array( $this, 'scf_save_settings' ) );
			add_action( 'wp_ajax_scf_get_leads', array( $this, 'scf_get_leads' ) );
			add_action( 'wp_ajax_scf_delete_leads', array( $this, 'scf_delete_leads' ) );
		}

		// sanitized form data
		function sanitize_form_data($data)
		{
			$data = array_map('sanitize_text_field', $data);
			$data = array_map('stripslashes', $data);
			return $data;
		}


		// get inputs from body
		public function sanitize_inputs( $array_or_string ) {
			if ( is_string( $array_or_string ) ) {
				$array_or_string = sanitize_text_field( $array_or_string );
			} elseif ( is_array( $array_or_string ) ) {
				foreach ( $array_or_string as $key => &$value ) {
					if ( is_array( $value ) ) {
						$value = $this->sanitize_inputs( $value );
					} else {
						$value = sanitize_text_field( $value );
					}
				}
			}

			return $array_or_string;
		}

		// save options
		public function scf_save_settings() {
			$options = \WPPOOL\SCF\App::options();

			$request = $this->sanitize_inputs( $_POST );
			$updated = array();

			foreach ( $options as $option_name => $option_value ) {
				$name  = 'scf_' . $option_name;
				$value = $request['options'][ $option_name ] ?? $option_value;

				update_option( $name, $value );

				$updated[ $name ] = $value;
			}

			$response = array(
				'success' => true,
				'data'    => $request['options'],
				'updated' => $updated,
			);

			wp_send_json( $response );
		}

		# scf get leads
		public function scf_get_leads() { 
			
			$leads = Lead::get_all(); 

			if( $leads ) {
				$response = array(
					'success' => true,
					'data'    => $leads,
				);
			} else {
				$response = array(
					'success' => false,
					'data'    => array(),
				);
			}

			wp_send_json( $response );
 
		}

		# scf delete multiple leads
		public function scf_delete_leads() {
			$ids = sanitize_text_field( $_REQUEST['ids'] ?? '' );

			$ids = explode( ',', $ids );   

			$deleted = Lead::delete_multiple( $ids );
			

			if( $deleted ) {
				$response = array(
					'success' => true,
					'data'    => $deleted,
				);
			} else {
				$response = array(
					'success' => false,
					'data'    => array(),
				);
			}

			wp_send_json( $response );
		}
	}

	// if doing ajax 
	if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
		new Ajax();
	} 
endif;
