<?php

namespace WPPOOL\SCF;

if (!class_exists('\WPPOOL\SCF\Admin')) :
	final class Admin
	{

		public $appsero = null;
		/**
		 * Common trait for admin and frontend
		 */
		use \WPPOOL\SCF\Common;

		public function __construct()
		{
			register_activation_hook(SCF_FILE, array($this, 'activate_scf'));
			add_action('init', array($this, 'register_scf_settings'));

			add_action('admin_init', array($this, 'safe_redirection_to_setup'));
			add_action('admin_menu', array($this, 'register_scf_admin_menu'), 0);
			add_action('admin_enqueue_scripts', array($this, 'scf_enqueue_scripts'));
			// add_action('scf_setting_footer', array($this, 'scf_setting_footer'));  

			# appsero 
			add_action('init', [$this, 'init_appsero']);

			add_filter('plugin_action_links_' . plugin_basename(SCF_FILE), array($this, 'plugin_action_links'));

			# development
			add_filter('scf_is_dev', '__return_true');
		}

		// activate
		public function activate_scf()
		{
			# Reset setup wizard
			update_option('scf-setup-run', false);


			$this->initialize_scf_table();
		}

		# create scf table 
		public function initialize_scf_table()
		{
			# Create database tables
			Lead::create_table();
		}


		// safe redirection to setup page
		public function safe_redirection_to_setup()
		{
			if (!scf_is_setup_run()) {
				update_option('scf-setup-run', true);
				wp_redirect(admin_url('admin.php?page=scf'));
				exit;
			}
		}

		// Register default settings
		function register_scf_settings()
		{

			$options = \WPPOOL\SCF\App::options();
			foreach ($options as $option_name => $option_default) {
				$option_name = 'scf_' . $option_name;

				register_setting('scf_settings', $option_name);

				add_option($option_name, $option_default);
			}
		}

		// Register admin menu
		public function register_scf_admin_menu()
		{
			// Menu page
			add_menu_page(
				__('Social Contact Form', 'social-contact-form'),
				__('Social Contact Form', 'social-contact-form'),
				'manage_options',
				'scf',
				array($this, 'render_settings_page'),
				'dashicons-scf'
			);

			// submenu with same slug as parent
			add_submenu_page(
				'scf',
				__('Social Contact Form Settings', 'social-contact-form'),
				__('Settings', 'social-contact-form'),
				'manage_options',
				'scf',
				array($this, 'render_settings_page')
			);

			add_submenu_page(
				'scf',
				__('Social Contact Form Leads', 'social-contact-form'),
				__('Leads', 'social-contact-form'),
				'manage_options',
				'scf-leads',
				array($this, 'render_leads_page')
			);

			do_action('scf_admin_menu');
		}

		// render settings page
		public function render_settings_page()
		{
			$options = scf_get_options();
			scf_render('admin/settings', $options);
		}

		// render leads page
		public function render_leads_page()
		{
			scf_render('admin/leads');
		}

		public function scf_custom_icon()
		{
			$image = SCF_PUBLIC . '/images/icon-white.svg';
			$css = '.dashicons-scf {
				background: url("' . esc_url($image) . '") no-repeat center center !important; 
				background-size: 40% !important;
				width: 37px !important;
			}';

			wp_enqueue_style('scf_inline_style', SCF_PUBLIC . '/css/blank.css');
			wp_add_inline_style('scf_inline_style', $css, 99);
		}

		public function scf_enqueue_scripts($hook = '')
		{

			$this->scf_custom_icon();

			if (!in_array($hook, array('toplevel_page_scf', 'social-contact-form_page_scf-leads'))) {
				return false;
			}

			wp_enqueue_script('jquery');
			wp_enqueue_media();
			wp_enqueue_style('social-contact-form-admin', SCF_PUBLIC . '/css/admin.min.css', time());
			wp_enqueue_style('social-contact-form-frontend', SCF_PUBLIC . '/css/frontend.min.css', time());
			wp_enqueue_script('social-contact-form-admin', SCF_PUBLIC . '/js/admin.min.js', array('jquery'), time(), true);

			$scf_instance = new \WPPOOL\Product('social-contact-form');

			wp_localize_script(
				'social-contact-form-admin',
				'scf_admin',
				array(
					'ajax_url' => admin_url('admin-ajax.php'),
					'public'   => SCF_PUBLIC . '/',
					'nonce'    => wp_create_nonce('scf_nonce'),
					'is_pro'   => is_scf_ultimate(),
					'options'  => scf_get_options(),
					'filters'  => [
						'per_page' => apply_filters('scf_leads_per_page', 100),
					],
					'countries' => App::countries(),
					'development' => scf_is_dev(),
					'fields' => App::fields(),
					'offer' => $scf_instance->offer(),
				)
			);

			$premium_fonts = App::premium_fonts();

			$css = "";

			if ($premium_fonts) {
				foreach ($premium_fonts as $font) {

					$font_url = SCF_PUBLIC . '/fonts/' . (str_replace(' ', '+', $font)) . '.ttf';
					$fontFamily = $this->formatFont($font);

					$css .= "@font-face {
					font-family: {$fontFamily} !important; 
					src: url({$font_url}) format('ttf') !important;	
					font-style: normal !important;
					font-weight: 400 !important; 
				  }";
				}
			}

			wp_add_inline_style('social-contact-form-frontend', $css, 99);
		}

		// show admin notice
		function scf_admin_notices()
		{
			global $pagenow;
			if ($pagenow == 'edit.php' && isset($_GET['post_type']) && $_GET['post_type'] == 'scf_messages') {
				$scf = get_option('scf_options');
				if (!isset($scf['whatsapp_number']) || empty($scf['whatsapp_number']) && $scf['whatsapp'] == 1) {
					echo wp_sprintf(
						'<div class="notice notice-error is-dismissible">
                            <p>%s</p>
                        </div>',
						wp_sprintf('Please enter WhatsApp number in the %s to use Social Contact Form', '<a href="' . admin_url('edit.php?post_type=scf_messages&page=social-contact-form') . '">Settings page</a>')
					);
				}
			}
		}

		// plugin activation links
		function plugin_action_links($links)
		{
			if (is_scf_ultimate()) {
				$links[] = '<a href="' . admin_url('admin.php?page=scf') . '">' . __('Settings', 'social-contact-form') . '</a>';
			} else {
				$links[] = '<a href="https://go.wppool.dev/2rc7/?ref=' . esc_url(home_url()) . '" target="_blank" style="color: #b32d2e;">' . __('Upgrade', 'social-contact-form') . '</a>';
			}
			return $links;
		}

		# Init appsero
		public function init_appsero()
		{
			if (class_exists('\SocialContactForm\Appsero\Client')) {
				$this->appsero = new \SocialContactForm\Appsero\Client('9b39bac1-3b27-41d1-aeec-18fbfd4a9977', 'Social Contact Form', SCF_FILE);
				$this->appsero->set_textdomain('social-contact-form');
				// Active insights
			
				$this->appsero->insights()->init(); 
			}
		}

		public function formatFont($font = '')
		{
			$fonts = explode(',', $font);
			$fonts = array_map(function ($font) {
				// if space found in font name
				if (strpos($font, ' ') !== false) {
					$font = "'" . $font . "'";
				}
				return $font;
			}, $fonts);


			return implode(', ', $fonts);
		}

	}


	// init
	new Admin();
endif;
